@@ -105,27 +105,54 @@ enum {
 };
 typedef NSUInteger NSRequestUserAttentionType;
 
-#define NSAppKitVersionNumber10_0   577
-#define NSAppKitVersionNumber10_1   620
-#define NSAppKitVersionNumber10_2   663
-#define NSAppKitVersionNumber10_2_3 663.6
-#define NSAppKitVersionNumber10_3   743
-#define NSAppKitVersionNumber10_3_2 743.14
-#define NSAppKitVersionNumber10_3_3 743.2
-#define NSAppKitVersionNumber10_3_5 743.24
-#define NSAppKitVersionNumber10_3_7 743.33
-#define NSAppKitVersionNumber10_3_9 743.36
-#define NSAppKitVersionNumber10_4   824
-#define NSAppKitVersionNumber10_4_1 824.1
-#define NSAppKitVersionNumber10_4_3 824.23
-#define NSAppKitVersionNumber10_4_4 824.33
-#define NSAppKitVersionNumber10_4_7 824.41
-#define NSAppKitVersionNumber10_5   949
-#define NSAppKitVersionNumber10_5_2 949.27
-#define NSAppKitVersionNumber10_5_3 949.33
-#define NSAppKitVersionNumber10_6   1038
-#define NSAppKitVersionNumber10_7   1138
-#define NSAppKitVersionNumber10_7_2 1138.23
+#define NSAppKitVersionNumber10_0      577
+#define NSAppKitVersionNumber10_1      620
+#define NSAppKitVersionNumber10_2      663
+#define NSAppKitVersionNumber10_2_3    663.6
+#define NSAppKitVersionNumber10_3      743
+#define NSAppKitVersionNumber10_3_2    743.14
+#define NSAppKitVersionNumber10_3_3    743.2
+#define NSAppKitVersionNumber10_3_5    743.24
+#define NSAppKitVersionNumber10_3_7    743.33
+#define NSAppKitVersionNumber10_3_9    743.36
+#define NSAppKitVersionNumber10_4      824
+#define NSAppKitVersionNumber10_4_1    824.1
+#define NSAppKitVersionNumber10_4_3    824.23
+#define NSAppKitVersionNumber10_4_4    824.33
+#define NSAppKitVersionNumber10_4_7    824.41
+#define NSAppKitVersionNumber10_5      949
+#define NSAppKitVersionNumber10_5_2    949.27
+#define NSAppKitVersionNumber10_5_3    949.33
+#define NSAppKitVersionNumber10_6      1038
+#define NSAppKitVersionNumber10_7      1138
+#define NSAppKitVersionNumber10_7_2    1138.23;
+#define NSAppKitVersionNumber10_7_3    1138.32;
+#define NSAppKitVersionNumber10_7_4    1138.47;
+#define NSAppKitVersionNumber10_8      1187;
+#define NSAppKitVersionNumber10_9      1265;
+#define NSAppKitVersionNumber10_10     1343;
+#define NSAppKitVersionNumber10_10_2   1344;
+#define NSAppKitVersionNumber10_10_3   1347;
+#define NSAppKitVersionNumber10_10_4   1348;
+#define NSAppKitVersionNumber10_10_5   1348;
+#define NSAppKitVersionNumber10_10_Max 1349;
+#define NSAppKitVersionNumber10_11     1404;
+#define NSAppKitVersionNumber10_11_1   1404.13;
+#define NSAppKitVersionNumber10_11_2   1404.34;
+#define NSAppKitVersionNumber10_11_3   1404.34;
+#define NSAppKitVersionNumber10_12     1504;
+#define NSAppKitVersionNumber10_12_1   1504.60;
+#define NSAppKitVersionNumber10_12_2   1504.76;
+#define NSAppKitVersionNumber10_13     1561;
+#define NSAppKitVersionNumber10_13_1   1561.1;
+#define NSAppKitVersionNumber10_13_2   1561.2;
+#define NSAppKitVersionNumber10_13_4   1561.4;
+#define NSAppKitVersionNumber10_14     1671;
+#define NSAppKitVersionNumber10_14_1   1671.1;
+#define NSAppKitVersionNumber10_14_2   1671.2;
+#define NSAppKitVersionNumber10_14_3   1671.3;
+#define NSAppKitVersionNumber10_14_4   1671.4;
+#define NSAppKitVersionNumber10_14_5   1671.5;
 
 APPKIT_EXPORT const double NSAppKitVersionNumber;
 #endif
@@ -750,6 +777,16 @@ NSShowSystemInfoPanel(NSDictionary *options);
  */
 APPKIT_EXPORT NSApplication	*NSApp;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+enum
+{
+  NSModalResponseStop = -1000,
+  NSModalResponseAbort = -1001,
+  NSModalResponseContinue = -1002
+};
+typedef NSInteger NSModalResponse;
+#endif
+
 #if defined(__cplusplus)
 }
 #endif
