@@ -31,9 +31,10 @@
 #define _GNUstep_H_NSEvent
 #import <GNUstepBase/GSVersionMacros.h>
 
-#include <Foundation/NSCoder.h>
-#include <Foundation/NSGeometry.h>
-#include <Foundation/NSDate.h>
+#import <Foundation/NSObject.h>
+#import <Foundation/NSGeometry.h>
+// For NSTimeInterval
+#import <Foundation/NSDate.h>
 
 @class NSString;
 @class NSWindow;
@@ -70,7 +71,7 @@
   NSScrollWheel
  </example>
  */
-typedef enum _NSEventType {
+enum _NSEventType {
   // Note - order IS significant as ranges of values
   // are used for testing for valid event types.
   NSLeftMouseDown = 1,
@@ -98,7 +99,8 @@ typedef enum _NSEventType {
   NSOtherMouseDown = 25,
   NSOtherMouseUp,
   NSOtherMouseDragged
-} NSEventType;
+};
+typedef NSUInteger NSEventType;
 
 enum {
   NSLeftMouseDownMask = (1 << NSLeftMouseDown),
@@ -155,13 +157,16 @@ enum {
                         | NSLeftMouseDraggedMask | NSMouseMovedMask
                         | NSRightMouseUpMask | NSOtherMouseUpMask)
 };
+typedef unsigned long long NSEventMask;
 
 /*
  * Convert an NSEvent Type to it's respective Event Mask
  */
 // FIXME: Should we use the inline trick from NSGeometry.h here? 
-static inline
-unsigned int
+static inline NSEventMask
+NSEventMaskFromType(NSEventType type);
+
+static inline NSEventMask
 NSEventMaskFromType(NSEventType type)
 {
   return (1 << type);
@@ -180,15 +185,18 @@ enum {
   NSHelpKeyMask = 64 << 16,
   NSFunctionKeyMask = 128 << 16
 };
+typedef NSUInteger NSEventModifierFlags;
+
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
-typedef enum
+enum
 {
   NSUnknownPointingDevice,
   NSPenPointingDevice,
   NSCursorPointingDevice,
   NSEraserPointingDevice
-} NSPointingDeviceType;
+};
+typedef NSUInteger NSPointingDeviceType;
 
 enum
 {
@@ -196,6 +204,7 @@ enum
   NSPenLowerSideMask = 2,
   NSPenUpperSideMask = 4
 };
+typedef NSUInteger NSEventButtonMask;
 
 enum
 {
@@ -220,63 +229,90 @@ enum
 
 #endif
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+enum {
+  NSEventPhaseNone = 0,
+  NSEventPhaseBegan = 1,
+  NSEventPhaseStationary = 2,
+  NSEventPhaseChanged = 4,
+  NSEventPhaseEnded = 8,
+  NSEventPhaseCancelled = 16,
+  NSEventPhaseMayBegin = 32
+};
+typedef NSUInteger NSEventPhase;
+
+enum {
+  NSEventGestureAxisNone = 0,
+  NSEventGestureAxisHorizontal,
+  NSEventGestureAxisVertical
+};
+typedef NSInteger NSEventGestureAxis;
+
+enum {
+  NSEventSwipeTrackingLockDirection = 1,
+  NSEventSwipeTrackingClampGestureAmount = 2
+};
+typedef NSUInteger NSEventSwipeTrackingOptions;
+
+#endif
+
 @interface NSEvent : NSObject <NSCoding, NSCopying>
 {
   NSEventType	event_type;
   NSPoint	location_point;
-  unsigned int modifier_flags;
+  NSUInteger modifier_flags;
   NSTimeInterval event_time;
-  int window_num;
-  NSGraphicsContext	*event_context;
+  NSInteger window_num;
+  NSGraphicsContext *event_context;
   union _MB_event_data
     {
       struct
         {
-          int   event_num;
-          short click;
-          short button;
+          NSInteger event_num;
+          NSInteger click;
+          NSInteger button;
           float pressure;
-          float deltaX;
-          float deltaY;
-          float deltaZ;
+          CGFloat deltaX;
+          CGFloat deltaY;
+          CGFloat deltaZ;
         } mouse;
       struct
         {
           BOOL     repeat;
-          NSString *char_keys;
-          NSString *unmodified_keys;
+          __unsafe_unretained NSString *char_keys;
+          __unsafe_unretained NSString *unmodified_keys;
           unsigned short key_code;
         } key;
       struct
         {
-          int  event_num;
-          int  tracking_num;
+          NSInteger event_num;
+          NSInteger tracking_num;
           void *user_data;
         } tracking;
       struct
         {
           short sub_type;
-          int   data1;
-          int   data2;
+          NSInteger data1;
+          NSInteger data2;
         } misc;
     } event_data;
 }
 
 + (NSEvent*) enterExitEventWithType: (NSEventType)type        
                            location: (NSPoint)location
-                      modifierFlags: (unsigned int)flags
+                      modifierFlags: (NSUInteger)flags
                           timestamp: (NSTimeInterval)time
-                       windowNumber: (int)windowNum
+                       windowNumber: (NSInteger)windowNum
                             context: (NSGraphicsContext*)context        
-                        eventNumber: (int)eventNum
-                     trackingNumber: (int)trackingNum
+                        eventNumber: (NSInteger)eventNum
+                     trackingNumber: (NSInteger)trackingNum
                            userData: (void *)userData; 
 
 + (NSEvent*) keyEventWithType: (NSEventType)type
                      location: (NSPoint)location
-                modifierFlags: (unsigned int)flags
+                modifierFlags: (NSUInteger)flags
                     timestamp: (NSTimeInterval)time
-                 windowNumber: (int)windowNum
+                 windowNumber: (NSInteger)windowNum
                       context: (NSGraphicsContext*)context        
                    characters: (NSString *)keys        
   charactersIgnoringModifiers: (NSString *)ukeys
@@ -285,41 +321,41 @@ enum
 
 + (NSEvent*) mouseEventWithType: (NSEventType)type        
                        location: (NSPoint)location
-                  modifierFlags: (unsigned int)flags
+                  modifierFlags: (NSUInteger)flags
                       timestamp: (NSTimeInterval)time
-                   windowNumber: (int)windowNum        
+                   windowNumber: (NSInteger)windowNum        
                         context: (NSGraphicsContext*)context        
-                    eventNumber: (int)eventNum        
-                     clickCount: (int)clickNum        
+                    eventNumber: (NSInteger)eventNum        
+                     clickCount: (NSInteger)clickNum        
                        pressure: (float)pressureValue;
 
 #if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
 + (NSEvent*) mouseEventWithType: (NSEventType)type        
                        location: (NSPoint)location
-                  modifierFlags: (unsigned int)flags
+                  modifierFlags: (NSUInteger)flags
                       timestamp: (NSTimeInterval)time
-                   windowNumber: (int)windowNum        
+                   windowNumber: (NSInteger)windowNum        
                         context: (NSGraphicsContext*)context        
-                    eventNumber: (int)eventNum        
-                     clickCount: (int)clickNum        
+                    eventNumber: (NSInteger)eventNum        
+                     clickCount: (NSInteger)clickNum        
                        pressure: (float)pressureValue
-                   buttonNumber: (int)buttonNum
-                         deltaX: (float)deltaX
-                         deltaY: (float)deltaY
-                         deltaZ: (float)deltaZ;
+                   buttonNumber: (NSInteger)buttonNum
+                         deltaX: (CGFloat)deltaX
+                         deltaY: (CGFloat)deltaY
+                         deltaZ: (CGFloat)deltaZ;
 #endif
 
 + (NSPoint)mouseLocation;
 
 + (NSEvent*) otherEventWithType: (NSEventType)type
                        location: (NSPoint)location
-                  modifierFlags: (unsigned int)flags
+                  modifierFlags: (NSUInteger)flags
                       timestamp: (NSTimeInterval)time
-                   windowNumber: (int)windowNum
+                   windowNumber: (NSInteger)windowNum
                         context: (NSGraphicsContext*)context
                         subtype: (short)subType
-                          data1: (int)data1
-                          data2: (int)data2;
+                          data1: (NSInteger)data1
+                          data2: (NSInteger)data2;
 
 + (void) startPeriodicEventsAfterDelay: (NSTimeInterval)delaySeconds
                             withPeriod: (NSTimeInterval)periodSeconds;
@@ -327,55 +363,80 @@ enum
 
 
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
-- (int) buttonNumber;
+- (NSInteger) buttonNumber;
 #endif
 - (NSString *) characters;
 - (NSString *) charactersIgnoringModifiers;
-- (int) clickCount;
+- (NSInteger) clickCount;
 - (NSGraphicsContext*) context;
-- (int) data1;
-- (int) data2;
+- (NSInteger) data1;
+- (NSInteger) data2;
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
-- (float)deltaX;
-- (float)deltaY;
-- (float)deltaZ;
+- (CGFloat)deltaX;
+- (CGFloat)deltaY;
+- (CGFloat)deltaZ;
 #endif
-- (int) eventNumber;
+- (NSInteger) eventNumber;
 - (BOOL) isARepeat;
 - (unsigned short) keyCode;
 - (NSPoint) locationInWindow;
-- (unsigned int) modifierFlags;
+- (NSEventModifierFlags) modifierFlags;
 - (float) pressure;
 - (short) subtype;
 - (NSTimeInterval) timestamp;
-- (int) trackingNumber;
+- (NSInteger) trackingNumber;
 - (NSEventType) type;
 - (void *) userData;
 - (NSWindow *) window;
-- (int) windowNumber;
+- (NSInteger) windowNumber;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+- (NSEventMask) associatedEventsMask;
+#endif
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
-- (int) absoluteX;
-- (int) absoluteY;
-- (int) absoluteZ;
-- (unsigned int) buttonMask;
-- (unsigned int) capabilityMask;
-- (unsigned int) deviceID;
+- (NSInteger) absoluteX;
+- (NSInteger) absoluteY;
+- (NSInteger) absoluteZ;
+- (NSEventButtonMask) buttonMask;
+- (NSUInteger) capabilityMask;
+- (NSUInteger) deviceID;
 - (BOOL) isEnteringProximity;
-- (unsigned int) pointingDeviceID;
-- (unsigned int) pointingDeviceSerialNumber;
+- (NSUInteger) pointingDeviceID;
+- (NSUInteger) pointingDeviceSerialNumber;
 - (NSPointingDeviceType) pointingDeviceType;
 - (float) rotation;
-- (unsigned int) systemTabletID;
-- (unsigned int) tabletID;
+- (NSUInteger) systemTabletID;
+- (NSUInteger) tabletID;
 - (float) tangentialPressure;
 - (NSPoint) tilt;
 - (unsigned long long) uniqueID;
 - (id) vendorDefined;
-- (unsigned int) vendorID;
-- (unsigned int) vendorPointingDeviceType;
+- (NSUInteger) vendorID;
+- (NSUInteger) vendorPointingDeviceType;
 #endif
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
++ (NSEvent*) eventWithEventRef: (const void *)eventRef;
+//+ (NSEvent*) eventWithCGEvent: (CGEventRef)cgEvent;
+- (const void *) eventRef;
+//- (CGEventRef) CGEvent;
++ (void) setMouseCoalescingEnabled: (BOOL)flag;
++ (BOOL) isMouseCoalescingEnabled;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
++ (NSEventModifierFlags) modifierFlags;
++ (NSTimeInterval) keyRepeatDelay;
++ (NSTimeInterval) keyRepeatInterval;
++ (NSUInteger) pressedMouseButtons;
++ (NSTimeInterval) doubleClickInterval;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+- (NSEventPhase) phase;
+- (NSEventPhase) momentumPhase;
+#endif
 @end
 
 enum {
@@ -453,11 +514,6 @@ enum {
   NSModeSwitchFunctionKey = 0xF747
 };
 
-/*
- * Convert an Event Mask Type to a Mask
- */
-unsigned int NSEventMaskFromType(NSEventType type);
-
 #if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
 typedef enum {
   GSAppKitWindowMoved = 1,
@@ -474,7 +530,9 @@ typedef enum {
   GSAppKitDraggingExit,
   GSAppKitDraggingDrop,
   GSAppKitDraggingFinished,
-  GSAppKitRegionExposed
+  GSAppKitRegionExposed,
+  GSAppKitWindowDeminiaturize,
+  GSAppKitAppHide
 } GSAppKitSubtype;
 #endif
 
