@@ -96,13 +96,13 @@
 - (BOOL) outlineView: (NSOutlineView *)outlineView 
           acceptDrop: (id <NSDraggingInfo>)info 
                 item: (id)item 
-          childIndex: (int)index;
+          childIndex: (NSInteger)index;
 /**
  * Implementation of this method is required.  Returns the child at 
  * the specified index for the given item.
  */
 - (id) outlineView: (NSOutlineView *)outlineView 
-             child: (int)index 
+             child: (NSInteger)index 
             ofItem: (id)item;
 /**
  * This is a required method.  Returns whether or not the outline view
@@ -121,7 +121,7 @@
  * This is a required method.  Returns the number of children of
  * the given item.
  */
-- (int) outlineView: (NSOutlineView *)outlineView
+- (NSInteger) outlineView: (NSOutlineView *)outlineView
   numberOfChildrenOfItem: (id)item;
 
 /**
@@ -154,7 +154,7 @@
 - (NSDragOperation) outlineView: (NSOutlineView*)outlineView 
                    validateDrop: (id <NSDraggingInfo>)info 
                    proposedItem: (id)item 
-             proposedChildIndex: (int)index;
+             proposedChildIndex: (NSInteger)index;
 
 /**
  * Causes the outline view to write the specified items to the pastboard.
@@ -178,7 +178,9 @@ namesOfPromisedFilesDroppedAtDestination: (NSURL *)dropDestination
 /*
  * Constants
  */
-extern const int NSOutlineViewDropOnItemIndex;
+enum {
+  NSOutlineViewDropOnItemIndex = -1
+};
 
 /*
  * Notifications
@@ -268,6 +270,13 @@ shouldSelectTableColumn: (NSTableColumn *)tableColumn;
       willDisplayCell: (id)cell
        forTableColumn: (NSTableColumn *)tableColumn
                  item: (id)item;  
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (NSCell *) outlineView: (NSOutlineView *)outlineView 
+  dataCellForTableColumn: (NSTableColumn *)aTableColumn
+		    item: (id)item;
+#endif
+
 /**
  * Called when the given cell in the outline column is about to be displayed.  This method is
  * useful for making last second modifications to what will be shown.
